/*
 * Copyright (c) 2014, Oracle and/or its affiliates. All rights reserved.
 * Copyright (C) 2014-2017, IS2T - EDC compliance and optimizations.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package com.is2t.support.net.natives;

import java.net.MulticastSocket;

import com.is2t.errors.NetErrors;

/**
 * {@link MulticastSocket} related natives.
 */
public class MulticastSocketChannelNatives {

	/**
	 * Get the default time-to-live for multicast packets sent out on the channel.
	 * @param nativeFD the datagram socket file descriptor
	 * @param retry true when the previous call returned {@link NetErrors#J_NET_NATIVE_CODE_BLOCKED_WITHOUT_RESULT}
	 * and the calling process repeats the call to this operation for its completion
	 * @return the default time-to-live value or negative error code
	 * @see {@link NetErrors} for error codes
	 */
	public static native int getTimeToLive(int nativeFD, boolean retry);

	/**
	 * Set the default time-to-live for multicast packets sent out
	 * on this channel in order to control the scope of the multicasts.
	 * The ttl <B>must</B> be in the range {@code  0 <= ttl <= 255}
	 * Multicast packets sent with a TTL of {@code 0} are not transmitted
	 * on the network but may be delivered locally.
	 * 
	 * @param nativeFD the datagram socket file descriptor
	 * @param ttl the TTL value to set
	 * @param retry true when the previous call returned {@link NetErrors#J_NET_NATIVE_CODE_BLOCKED_WITHOUT_RESULT}
	 * and the calling process repeats the call to this operation for its completion
	 * @return zero or negative error code
	 * @see {@link NetErrors} for error codes
	 */
	public static native int setTimeToLive(int nativeFD, int ttl, boolean retry);

	/**
	 * Joins or leaves a multicast group.

	 * @param fd the datagram socket file descriptor
	 * @param join join if true, leave if false
	 * @param mcastAddr is the multicast address to join
	 * @param mcastAddrLength the multicast address size
	 * @param netIfAddr is the address of the interface that must join
	 * @param netIfAddrLength the interface address size
	 * @param retry true when the previous call returned {@link NetErrors#J_NET_NATIVE_CODE_BLOCKED_WITHOUT_RESULT}
	 * and the calling process repeats the call to this operation for its completion
	 * @return zero or negative error code
	 * @see {@link NetErrors} for error codes
	 */
	public static native int joinOrLeave(int fd, boolean join, byte[] mcastAddr, int mcastAddrLength, byte[] netIfAddr, int netIfAddrLength, boolean retry);
}
