/*
 * Copyright (c) 2014, Oracle and/or its affiliates. All rights reserved.
 * Copyright (C) 2014-2018, IS2T - EDC compliance and optimizations.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package com.is2t.support.net.natives;

import com.is2t.errors.NetErrors;

public class NetworkAddressNatives {

	/**
	 * Gets the host address representing any local address.
	 * <p>When this method returns, the {@code anyLocalAddr} buffer is filled with the host address.
	 * 
	 * @param anyLocalAddr the buffer into which the host address will be stored
	 * @param length the buffer length
	 * @param retry true when the previous call returned {@link NetErrors#J_NET_NATIVE_CODE_BLOCKED_WITHOUT_RESULT}
	 * and the calling process repeats the call to this operation for its completion
	 * @return the host address size in bytes or {@link NetErrors#J_EHOSTUNKNOWN} error code
	 * if no any local address found or an error occurs
	 */
	public static native int lookupInaddrAny(byte[] anyLocalAddr, int length, boolean retry);

	/**
	 * Gets the local host name.
	 * <p>When this method returns, the {@code localHostname} buffer is filled with the local host name.
	 * 
	 * @param localHostname the buffer into which the local host name will be stored
	 * @param length the buffer length
	 * @param retry true when the previous call returned {@link NetErrors#J_NET_NATIVE_CODE_BLOCKED_WITHOUT_RESULT}
	 * and the calling process repeats the call to this operation for its completion
	 * @return the local host name length or {@link NetErrors#J_EHOSTUNKNOWN} error code
	 * if no local host found or an error occurs
	 */
	public static native int getLocalHostnameNative(byte[] localHostname, int length, boolean retry);

	/**
	 * Gets the loopback address.
	 * <p>When this method returns, the {@code loopback} buffer is filled with the loopback address.
	 * 
	 * @param loopback the buffer into which the loopback address will be stored
	 * @param length the buffer length
	 * @param retry true when the previous call returned {@link NetErrors#J_NET_NATIVE_CODE_BLOCKED_WITHOUT_RESULT}
	 * and the calling process repeats the call to this operation for its completion
	 * @return the loopback address size in bytes  or {@link NetErrors#J_EHOSTUNKNOWN} error code
	 * if no loopback address found or an error occurs
	 */
	public static native int loopbackAddress(byte[] loopback, int length, boolean retry);
}
