/*
 * Copyright (c) 2014, Oracle and/or its affiliates. All rights reserved.
 * Copyright (C) 2014-2016, IS2T - EDC compliance and optimizations.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

package com.is2t.support.net.security;

import java.net.InetAddress;
import java.net.SocketPermission;

public class NetSecurityManagerStub implements INetSecurityManager {

	@Override
	public void checkSetFactory(SecurityManager sm) {
		sm.checkPermission(new RuntimePermission("setFactory"));

	}

	@Override
	public void checkListen(SecurityManager sm, int port) {
		sm.checkPermission(new SocketPermission("localhost:"
				+ (port == 0 ? "1024-" : "" + port), "listen"));

	}

	@Override
	public void checkMulticast(SecurityManager sm, InetAddress addr) {
		  sm.checkPermission(new SocketPermission(addr.getHostAddress(),
                  "accept,connect"));
	}

	@Override
	public void checkAccept(SecurityManager sm, String host, int port) {
		// Use the toString() hack to do the null check.
		sm.checkPermission(new SocketPermission(host.toString() + ":" + port,
				"accept"));

	}

	@Override
	public void checkConnect(SecurityManager sm, String host, int port) {
		if (port == -1) {
			sm.checkPermission(new SocketPermission(host, "resolve"));
		} else {
			// Use the toString() hack to do the null check.
			sm.checkPermission(new SocketPermission(host.toString() + ":"
					+ port, "connect"));
		}

	}

}
