/*
 * Copyright (c) 2015, Oracle and/or its affiliates. All rights reserved.
 * Copyright (C) 2016-2017, IS2T - EDC compliance and optimizations.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package com.is2t.support.net.ssl;

import java.security.KeyStore;
import java.security.KeyStoreException;
import java.security.NoSuchAlgorithmException;
import java.security.UnrecoverableKeyException;

import javax.net.ssl.KeyManager;
import javax.net.ssl.KeyManagerFactorySpi;
import javax.net.ssl.X509KeyManager;

import com.is2t.support.net.ssl.x509.X509KeyManagerImpl;

/**
 *
 */
public class KeyManagerFactoryImpl extends KeyManagerFactorySpi {

	X509KeyManager keyManager;
	boolean isInitialized;
	@Override
	protected void engineInit(KeyStore ks, char[] password)
			throws KeyStoreException, NoSuchAlgorithmException, UnrecoverableKeyException {

		keyManager = new X509KeyManagerImpl(ks, password);
		isInitialized = true;

	}

	@Override
	protected KeyManager[] engineGetKeyManagers() {
		if (!isInitialized) {
			throw new IllegalStateException("KeyManagerFactoryImpl is not initialized");
		}
		return new KeyManager[] { keyManager };
	}

}
