/*
 * Copyright (c) 2015, Oracle and/or its affiliates. All rights reserved.
 * Copyright (C) 2015-2018, IS2T - EDC compliance and optimizations.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package com.is2t.support.net.ssl;


public interface SSLErrorConstants{

	int  J_SSL_NO_ERROR							=  0; /* not an error */
	int  J_EOF									= -1; /* end of file */
	int  J_CREATE_SSL_CONTEXT_ERROR				= -1; /* SSL Context creation error */
	int  J_CREATE_SSL_ERROR						= -1; /* SSL creation error */
	int  J_CONNECTION_RESET						= -2; /* connection reset by the peer */
	int  J_SOCKET_TIMEOUT						= -3; /* socket timeout */
	int  J_NATIVE_CODE_BLOCKED_WITHOUT_RESULT	= -4; /* the native code has been stopped (with a timeout or not) because result was not available */
	int  J_BLOCKING_QUEUE_LIMIT_REACHED			= -5; /* Dispatch blocking request queue is full and a new request can not be added now */
	int  J_CERT_PARSE_ERROR						= -6; /* certificate parsing error */
	int  J_BIG_CERT_OR_KEY_SIZE_ERROR			= -7; /* certificate or key size bigger than the immortal buffer used to process certificates and keys */
	int	 J_NO_TRUSTED_CERT						= -8; /* No trusted certificate found*/
	int	 J_NOT_CA_CERT							= -9; /* basic constraints check failed: intermediate certificate is not a CA certificate */
	int	 J_NAME_CHAINING_ERROR					= -10; /* subject/issuer name chaining error */
	int  J_BIG_KEY_PASSWORD_SIZE_ERROR			= -11; /* key password size bigger than the immortal buffer reserved for the keys passwords*/

	int  J_RSA_WRONG_TYPE_ERROR                 = -21; /* RSA wrong block type for RSA function */
	int  J_RSA_BUFFER_ERROR                     = -22; /* RSA buffer error output too small or input too large */
	int  J_BUFFER_ERROR                         = -23; /* output buffer too small or input too large */
	int  J_ALGO_ID_ERROR                        = -24; /* setting algo id error */
	int  J_PUBLIC_KEY_ERROR                     = -25; /* setting public key error */
	int  J_DATE_ERROR                          	= -26; /* setting date validity error */
	int  J_SUBJECT_ERROR                        = -27; /* setting subject name error */
	int  J_ISSUER_ERROR                         = -28; /* setting issuer  name error */
	int  J_CA_TRUE_ERROR                        = -29; /* setting CA basic constraint true error */
	int  J_EXTENSIONS_ERROR                     = -30; /* setting extensions error */

	int  J_ASN_VERSION_ERROR                    = -31; /* ASN version error invalid number */
	int  J_ASN_GETINT_ERROR                     = -32; /* ASN get big int error invalid data */
	int  J_ASN_RSA_KEY_ERROR                    = -33; /* ASN key init error invalid input */
	int  J_ASN_OBJECT_ID_ERROR                  = -34; /* ASN object id error invalid id */
	int  J_ASN_TAG_NULL_ERROR                   = -35; /* ASN tag error not null */
	int  J_ASN_EXPECT_0_ERROR                   = -36; /* ASN expect error not zero */
	int  J_ASN_BITSTR_ERROR                     = -37; /* ASN bit string error wrong id */
	int  J_ASN_UNKNOWN_OID_ERROR                = -38; /* ASN oid error unknown sum id */
	int  J_ASN_DATE_SZ_ERROR                    = -39; /* ASN date error bad size */
	int  J_ASN_BEFORE_DATE_ERROR                = -40; /* ASN date error current date before */
	int  J_ASN_AFTER_DATE_ERROR                 = -41; /* ASN date error current date after */
	int  J_ASN_SIG_OID_ERROR                    = -42; /* ASN signature error mismatched oid */
	int  J_ASN_TIME_ERROR                       = -43; /* ASN time error unknown time type */
	int  J_ASN_INPUT_ERROR                      = -44; /* ASN input error not enough data */
	int  J_ASN_SIG_CONFIRM_ERROR                = -45; /* ASN signature error confirm failure */
	int  J_ASN_SIG_HASH_ERROR                   = -46; /* ASN signature error unsupported hash type */
	int  J_ASN_SIG_KEY_ERROR                    = -47; /* ASN signature error unsupported key type */
	int  J_ASN_DH_KEY_ERROR                     = -48; /* ASN key init error invalid input */
	int  J_ASN_NTRU_KEY_ERROR                   = -49; /* ASN ntru key decode error invalid input */
	int  J_ASN_CRIT_EXT_ERROR                   = -50; /* ASN unsupported critical extension */
	int  J_ASN_NO_SIGNER_ERROR     		        = -51; /* ASN no signer to confirm failure */
	int  J_ASN_CRL_CONFIRM_ERROR   		        = -52; /* ASN CRL signature confirm failure */
	int  J_ASN_CRL_NO_SIGNER_ERROR 		        = -53; /* ASN CRL no signer to confirm failure */
	int  J_ASN_OCSP_CONFIRM_ERROR  		        = -54; /* ASN OCSP signature confirm failure */

	int  J_ECC_BAD_ARG_ERROR                   = -60; /* ECC input argument of wrong type */
	int  J_ASN_ECC_KEY_ERROR                   = -61; /* ASN ECC bad input */
	int  J_ECC_CURVE_OID_ERROR                 = -62; /* Unsupported ECC OID curve type */
	int  J_BAD_FUNC_ARG                        = -63; /* Bad function argument provided */
	int  J_NOT_COMPILED_IN                     = -64; /* Feature not compiled in */
	int  J_UNICODE_SIZE_ERROR                  = -65; /* Unicode password too big */
	int  J_NO_PASSWORD         		           = -66; /* no password provided by user */
	int  J_ALT_NAME_ERROR         		       = -67; /* alt name size problem too big */

	int  J_AES_GCM_AUTH_ERROR     		       = -70; /* AES-GCM Authentication check failure */
	int  J_AES_CCM_AUTH_ERROR     		       = -71; /* AES-CCM Authentication check failure */

	int  J_ASYNC_INIT_ERROR      		       = -80; /* Async Init error */
	int  J_BAD_ALIGN_ERROR         		       = -81; /* Bad alignment for operation no alloc */
	int  J_BAD_STATE_ERROR     		       	   = -82; /* Bad state operation */
	int  J_BAD_PADDING_ERROR       		       = -83; /* Bad padding msg not correct length  */
	int  J_REQ_ATTRIBUTE_ERROR     		       = -84; /* setting cert request attributes error */
	int  J_PKCS7_OID_ERROR         		       = -85; /* PKCS#7 mismatched OID error */
	int  J_PKCS7_RECIP_ERROR       		       = -86; /* PKCS#7 recipient error */
	int  J_FIPS_NOT_ALLOWED_ERROR  		       = -87; /* FIPS not allowed error */
	int  J_ASN_NAME_INVALID_ERROR  		       = -88; /* ASN name constraint error */
	int  J_RNG_FAILURE_ERROR       		       = -89; /* RNG Failed Reinitialize */
	int  J_HMAC_MIN_KEYLEN_ERROR   		       = -90; /* FIPS Mode HMAC Minimum Key Length error */
	int  J_RSA_PAD_ERROR           		       = -91; /* RSA Padding Error */
	int  J_LENGTH_ONLY_ERROR       		       = -92; /* Returning output length only */
	int  J_IN_CORE_FIPS_ERROR      		       = -93; /* In Core Integrity check failure */
	int  J_AES_KAT_FIPS_ERROR      		       = -94; /* AES KAT failure */
	int  J_DES3_KAT_FIPS_ERROR     		       = -95; /* DES3 KAT failure */
	int  J_HMAC_KAT_FIPS_ERROR     		       = -96; /* HMAC KAT failure */
	int  J_RSA_KAT_FIPS_ERROR      		       = -97; /* RSA KAT failure */
	int  J_DRBG_KAT_FIPS_ERROR     		       = -98; /* HASH DRBG KAT failure */
	int  J_DRBG_CONT_FIPS_ERROR    		       = -99; /* HASH DRBG Continious test failure */
	int  J_AESGCM_KAT_FIPS_ERROR   		       = -100; /* AESGCM KAT failure */
	int  J_INPUT_CASE_ERROR                    = -101; /* process input state error */
	int  J_PREFIX_ERROR                        = -102; /* bad index to key rounds  */
	int  J_MEMORY_ERROR                        = -103; /* out of memory            */
	int  J_VERIFY_FINISHED_ERROR               = -104; /* verify problem on finished */
	int  J_VERIFY_MAC_ERROR                    = -105; /* verify mac problem       */
	int  J_HEADER_PARSE_ERROR                  = -106; /* parse error on header    */
	int  J_UNKNOWN_HANDSHAKE_TYPE              = -107; /* weird handshake type     */
	int  J_SOCKET_ERROR                        = -108; /* error state on socket    */
	int  J_SOCKET_NODATA                       = -109; /* expected data not there */
	int  J_INCOMPLETE_DATA                     = -110; /* don't have enough data to complete task */
	int  J_UNKNOWN_RECORD_TYPE                 = -111; /* unknown type in record hdr */
	int  J_DECRYPT_ERROR                       = -112; /* error during decryption  */
	int  J_FATAL_ERROR                         = -113; /* recvd alert fatal error  */
	int  J_ENCRYPT_ERROR                       = -114; /* error during encryption  */
	int  J_NO_PEER_KEY                         = -116; /* need peer's key          */
	int  J_NO_PRIVATE_KEY                      = -117; /* need the private key     */
	int  J_RSA_PRIVATE_ERROR                   = -118; /* error during rsa priv op */
	int  J_NO_DH_PARAMS                        = -119; /* server missing DH params */
	int  J_BUILD_MSG_ERROR                     = -120; /* build message failure    */
	int  J_BAD_HELLO                           = -121; /* client hello malformed   */
	int  J_DOMAIN_NAME_MISMATCH                = -122; /* peer subject name mismatch */
	int  J_WANT_READ                           = -123; /* want read call again    */
	int  J_NOT_READY_ERROR                     = -124; /* handshake layer not ready */
	int  J_PMS_VERSION_ERROR                   = -125; /* pre m secret version error */
	int  J_VERSION_ERROR                       = -126; /* record layer version error */
	int  J_WANT_WRITE                          = -127; /* want write call again   */
	int  J_MALFORMED_BUFFER                    = -128; /* malformed buffer input   */
	int  J_VERIFY_CERT_ERROR                   = -129; /* verify cert error        */
	int  J_VERIFY_SIGN_ERROR                   = -130; /* verify sign error        */
	int  J_CLIENT_ID_ERROR                     = -131; /* psk client identity error  */
	int  J_SERVER_HINT_ERROR                   = -132; /* psk server hint error  */
	int  J_PSK_KEY_ERROR                       = -133; /* psk key error  */
	int  J_LENGTH_ERROR                        = -134; /* record layer length error */
	int  J_PEER_KEY_ERROR                      = -135; /* can't decode peer key */
	int  J_ZERO_RETURN                         = -136; /* peer sent close notify */
	int  J_SIDE_ERROR                          = -137; /* wrong client/server type */
	int  J_NO_PEER_CERT                        = -138; /* peer didn't send key */

	int  J_NTRU_KEY_ERROR                      = -140; /* NTRU key error  */
	int  J_NTRU_DRBG_ERROR                     = -141; /* NTRU drbg error  */
	int  J_NTRU_ENCRYPT_ERROR                  = -142; /* NTRU encrypt error  */
	int  J_NTRU_DECRYPT_ERROR                  = -143; /* NTRU decrypt error  */

	int  J_ECC_CURVETYPE_ERROR                 = -150; /* Bad ECC Curve Type */
	int  J_ECC_CURVE_ERROR                     = -151; /* Bad ECC Curve */
	int  J_ECC_PEERKEY_ERROR                   = -152; /* Bad Peer ECC Key */
	int  J_ECC_MAKEKEY_ERROR                   = -153; /* Bad Make ECC Key */
	int  J_ECC_EXPORT_ERROR                    = -154; /* Bad ECC Export Key */
	int  J_ECC_SHARED_ERROR                    = -155; /* Bad ECC Shared Secret */
	int  J_NOT_CA_ERROR                        = -157; /* Not a CA cert error */
	int  J_BAD_CERT_MANAGER_ERROR              = -159; /* Bad Cert Manager */
	int  J_OCSP_CERT_REVOKED                   = -160; /* OCSP Certificate revoked */
	int  J_CRL_CERT_REVOKED                    = -161; /* CRL Certificate revoked */
	int  J_CRL_MISSING                         = -162; /* CRL Not loaded */
	int  J_OCSP_NEED_URL                       = -165; /* OCSP need an URL for lookup */
	int  J_OCSP_CERT_UNKNOWN                   = -166; /* OCSP responder doesn't know */
	int  J_OCSP_LOOKUP_FAIL                    = -167; /* OCSP lookup not successful */
	int  J_MAX_CHAIN_ERROR                     = -168; /* max chain depth exceeded */
	int  J_SUITES_ERROR                        = -171; /* suites pointer error */
	int  J_SSL_NO_PEM_HEADER                   = -172; /* no PEM header found */
	int  J_OUT_OF_ORDER_ERROR                  = -173; /* out of order message */
	int  J_BAD_KEA_TYPE_ERROR                  = -174; /* bad KEA type found */
	int  J_SANITY_CIPHER_ERROR                 = -175; /* sanity check on cipher error */
	int  J_RECV_OVERFLOW_ERROR                 = -176; /* RXCB returned more than rqed */
	int  J_NO_PEER_VERIFY                      = -178; /* Need peer cert verify Error */
	int  J_UNKNOWN_HOST_NAME_ERROR             = -181; /* Unrecognized host name Error */
	int  J_UNKNOWN_MAX_FRAG_LEN_ERROR          = -182; /* Unrecognized max frag len Error */
	int  J_KEYUSE_SIGNATURE_ERROR              = -183; /* KeyUse digSignature error */
	int  J_KEYUSE_ENCIPHER_ERROR               = -185; /* KeyUse keyEncipher error */
	int  J_EXTKEYUSE_AUTH_ERROR                = -186; /* ExtKeyUse server|client_auth */
	int  J_SEND_OOB_READ_ERROR                 = -187; /* Send Cb out of bounds read */
	int  J_SECURE_RENEGOTIATION_ERROR          = -188; /* Invalid Renegotiation Info */
	int  J_SCR_DIFFERENT_CERT_ERROR            = -189; /* SCR Different cert error  */
	int  J_NO_CHANGE_CIPHER_ERROR              = -190; /* Finished before change cipher */
	int  J_SANITY_MSG_ERROR                    = -191; /* Sanity check on msg order error */
	int  J_DUPLICATE_MSG_ERROR                 = -192; /* Duplicate message error */
	int  J_UNSUPPORTED_SUITE                   = -193; /* unsupported cipher suite */
	int  J_MATCH_SUITE_ERROR                   = -194; /* can't match cipher suite */
	int  J_BAD_CERTTYPE     				   = -195; /* bad certificate type */
	int  J_BAD_ENCODED_CERT_FORMAT     		   = -196; /* bad file type */
	int  J_OPEN_RAN_ERROR		  			   = -197; /* opening random device error */
	int  J_READ_RAN_ERROR         		       = -198; /* reading random device error */
	int  J_WINCRYPT_ERROR         		       = -199; /* windows crypt init error */
	int  J_CRYPTGEN_ERROR         		       = -200; /* windows crypt generation error */
	int  J_RAN_BLOCK_ERROR        		       = -201; /* reading random device would block */
	int  J_UNKNOWN_ERROR					   = -202; /* unknown error */

}



