/*
 * Copyright (c) 2015, Oracle and/or its affiliates. All rights reserved.
 * Copyright (C) 2015-2019, IS2T - EDC compliance and optimizations.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package com.is2t.support.net.ssl;

import ej.bon.Immortals;

public class SSLResources {

	private static final String SSL_RESOURCES_PACKAGE_PREFIX = "com.is2t.ssl.embedded.";

	/**
	 * Default maximum certificate or key size
	 */
	private static final int DEFAULT_MAX_CERT_AND_KEY_SIZE = 2 * 1024;

	/**
	 * Default maximum size of the key password (including null
	 * terminated)
	 */
	private static final int DEFAULT_MAX_KEY_PASSWORD_SIZE = 80;
	
	/**
	 * Default maximum hostname size
	 */
	private static final int DEFAULT_MAX_HOSTNAME_SIZE = 256;

	public static byte[] CERT_BUFFER;
	public static byte[] KEY_PASSWORD_BUFFER;
	public static byte[] HOSTNAME_BUFFER;

	static {
		Immortals.run(new Runnable() {

			@Override
			public void run() {
				CERT_BUFFER = new byte[getMaxCertAndKeySize()];
				KEY_PASSWORD_BUFFER = new byte[getMaxKeyPasswordSize()];
				HOSTNAME_BUFFER = new byte[getMaxHostnameSize()];
			}

		});
	}

	/**
	 * The maximum certificate and key size
	 * Is the size of the immortal buffer that will be reserved to process certificates and keys.
	 */
	private static int getMaxCertAndKeySize() {
		return Integer.getInteger(SSL_RESOURCES_PACKAGE_PREFIX + "max.cert.key.size", DEFAULT_MAX_CERT_AND_KEY_SIZE);
	}

	/**
	 * The maximum size of the key password. Is the size of the immortal
	 * buffer that will be reserved for the key password.
	 */
	private static int getMaxKeyPasswordSize() {
		return Integer.getInteger(SSL_RESOURCES_PACKAGE_PREFIX + "max.key.password.size",
				DEFAULT_MAX_KEY_PASSWORD_SIZE);
	}
	
	/**
	 * The maximum size of the hostname. Is the size of the immortal
	 * buffer that will be reserved for the hostname.
	 */
	private static int getMaxHostnameSize() {
		return Integer.getInteger(SSL_RESOURCES_PACKAGE_PREFIX + "max.hostname.size",
				DEFAULT_MAX_HOSTNAME_SIZE);
	}

}
