/*
 * Copyright (c) 2015, Oracle and/or its affiliates. All rights reserved.
 * Copyright (C) 2017, IS2T - EDC compliance and optimizations.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package com.is2t.support.net.ssl;

import java.io.IOException;
import java.net.InetAddress;
import java.net.Socket;
import java.net.SocketException;

import javax.net.ssl.SSLException;
import javax.net.ssl.SSLServerSocket;

public class SSLServerSocketImpl extends SSLServerSocket {

	private AbstractSSLContext context;
	private boolean useServerMode = true; // server mode
	private boolean needClientAuth = false; // no client authentication by default

	SSLServerSocketImpl(AbstractSSLContext context) throws IOException {
		this.context = context;
	}

	SSLServerSocketImpl(AbstractSSLContext context, int port) throws IOException {
		super(port);
		initContext(context);
	}

	SSLServerSocketImpl(AbstractSSLContext context, int port, int backlog) throws IOException {
		super(port, backlog);
		initContext(context);
	}

	SSLServerSocketImpl(AbstractSSLContext context, int port, int backlog, InetAddress ifAddress) throws IOException {
		super(port, backlog, ifAddress);
		initContext(context);
	}

	private void initContext(AbstractSSLContext context) throws SSLException {
		if (context == null) {
			throw new SSLException("No SSL authentification context");
		}
		this.context = context;
	}

	@Override
	public Socket accept() throws IOException {
		if (isClosed()) {
			throw new SocketException("Socket is closed");
		}
		if (!isBound()) {
			throw new SocketException("Socket is not bound yet");
		}

		SSLSocketImpl s = new SSLSocketImpl(this.context, this.useServerMode, this.needClientAuth);
		implAccept(s);
		s.doneConnect();
		return s;
	}

	@Override
	public void setUseClientMode(boolean mode) {
		this.useServerMode = !mode;

	}

	@Override
	public boolean getUseClientMode() {
		return !useServerMode;
	}

	@Override
	public void setNeedClientAuth(boolean need) {
		this.needClientAuth = need;

	}

	@Override
	public boolean getNeedClientAuth() {
		return this.needClientAuth;
	}

}
