<?xml version="1.0"?>
<!DOCTYPE foo [
	<!ENTITY style SYSTEM "stylesheet.css">
]>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	version="1.0" xmlns:lxslt="http://xml.apache.org/xslt" xmlns:redirect="http://xml.apache.org/xalan/redirect"
	xmlns:stringutils="xalan://org.apache.tools.ant.util.StringUtils"
	extension-element-prefixes="redirect">
	<xsl:output method="html" indent="yes" encoding="UTF-8" />
	<xsl:decimal-format decimal-separator="."
		grouping-separator="," />
	<!-- Licensed to the Apache Software Foundation (ASF) under one or more 
		contributor license agreements. See the NOTICE file distributed with this 
		work for additional information regarding copyright ownership. The ASF licenses 
		this file to You under the Apache License, Version 2.0 (the "License"); you 
		may not use this file except in compliance with the License. You may obtain 
		a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless 
		required by applicable law or agreed to in writing, software distributed 
		under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES 
		OR CONDITIONS OF ANY KIND, either express or implied. See the License for 
		the specific language governing permissions and limitations under the License. -->

	<!-- Sample stylesheet to be used with Ant JUnitReport output. It creates 
		a set of HTML files a la javadoc where you can browse easily through all 
		packages and classes. -->
	<xsl:param name="output.dir" select="'.'" />
	<xsl:param name="TITLE">
		Testsuite Results
	</xsl:param>
	<xsl:param name="PRODUCT" />


	<xsl:template match="testsuites">
		<!-- create the index.html -->
		<redirect:write file="{$output.dir}/index.html">
			<xsl:call-template name="index.html" />
		</redirect:write>

		<!-- create the stylesheet.css -->
		<redirect:write file="{$output.dir}/stylesheet.css">
			<xsl:call-template name="stylesheet.css" />
		</redirect:write>

		<!-- create the overview-packages.html at the root -->
		<redirect:write file="{$output.dir}/overview-summary.html">
			<xsl:apply-templates select="." mode="overview.packages" />
		</redirect:write>

		<!-- create the all-packages.html at the root -->
		<redirect:write file="{$output.dir}/overview-frame.html">
			<xsl:apply-templates select="." mode="all.packages" />
		</redirect:write>

		<!-- create the all-classes.html at the root -->
		<redirect:write file="{$output.dir}/allclasses-frame.html">
			<xsl:apply-templates select="." mode="all.classes" />
		</redirect:write>

		<!-- create the all-tests.html at the root -->
		<redirect:write file="{$output.dir}/all-tests.html">
			<xsl:apply-templates select="." mode="all.tests" />
		</redirect:write>

		<!-- create the alltests-fails.html at the root -->
		<redirect:write file="{$output.dir}/alltests-fails.html">
			<xsl:apply-templates select="." mode="all.tests">
				<xsl:with-param name="type" select="'fails'" />
			</xsl:apply-templates>
		</redirect:write>

		<!-- create the alltests-errors.html at the root -->
		<redirect:write file="{$output.dir}/alltests-errors.html">
			<xsl:apply-templates select="." mode="all.tests">
				<xsl:with-param name="type" select="'errors'" />
			</xsl:apply-templates>
		</redirect:write>
		
		<!-- create the alltests-ignored.html at the root -->
		<redirect:write file="{$output.dir}/alltests-ignored.html">
			<xsl:apply-templates select="." mode="all.tests">
				<xsl:with-param name="type" select="'ignored'" />
			</xsl:apply-templates>
		</redirect:write>
		
		<!-- create the alltests-triedAgain.html at the root -->
		<redirect:write file="{$output.dir}/alltests-triedAgain.html">
			<xsl:apply-templates select="." mode="all.tests">
				<xsl:with-param name="type" select="'triedAgain'" />
			</xsl:apply-templates>
		</redirect:write>
		
		<!-- process all packages -->
		<xsl:for-each
			select="./testsuite[not(./@package = preceding-sibling::testsuite/@package)]">
			<xsl:call-template name="package">
				<xsl:with-param name="name" select="@package" />
			</xsl:call-template>
		</xsl:for-each>
	</xsl:template>


	<xsl:template name="package">
		<xsl:param name="name" />
		<xsl:variable name="package.dir">
			<xsl:if test="not($name = '')">
				<xsl:value-of select="translate($name,'.','/')" />
			</xsl:if>
			<xsl:if test="$name = ''">
				.
			</xsl:if>
		</xsl:variable>
		<!--Processing package <xsl:value-of select="@name"/> in <xsl:value-of 
			select="$output.dir"/> -->
		<!-- create a classes-list.html in the package directory -->
		<redirect:write file="{$output.dir}/{$package.dir}/package-frame.html">
			<xsl:call-template name="classes.list">
				<xsl:with-param name="name" select="$name" />
			</xsl:call-template>
		</redirect:write>

		<!-- create a package-summary.html in the package directory -->
		<redirect:write file="{$output.dir}/{$package.dir}/package-summary.html">
			<xsl:call-template name="package.summary">
				<xsl:with-param name="name" select="$name" />
			</xsl:call-template>
		</redirect:write>

		<!-- for each class, creates a @name.html -->
		<!-- @bug there will be a problem with inner classes having the same name, 
			it will be overwritten -->
		<xsl:for-each select="/testsuites/testsuite[@package = $name]">
			<redirect:write file="{$output.dir}/{$package.dir}/{@id}_{@name}.html">
				<xsl:apply-templates select="." mode="class.details" />
			</redirect:write>
			<xsl:if test="string-length(./system-out)!=0">
				<redirect:write
					file="{$output.dir}/{$package.dir}/{@id}_{@name}-out.html">
					<html class="report">
						<head>
							<title>
								Standard Output from
								<xsl:value-of select="@name" />
							</title>
						</head>
						<body class="report-body">
							<pre>
								<xsl:value-of select="./system-out" />
							</pre>
						</body>
					</html>
				</redirect:write>
			</xsl:if>
			<xsl:if test="string-length(./system-err)!=0">
				<redirect:write
					file="{$output.dir}/{$package.dir}/{@id}_{@name}-err.html">
					<html class="report">
						<head>
							<title>
								Standard Error from
								<xsl:value-of select="@name" />
							</title>
						</head>
						<body class="report-body">
							<pre>
								<xsl:value-of select="./system-err" />
							</pre>
						</body>
					</html>
				</redirect:write>
			</xsl:if>
			<xsl:if test="@failures != 0">
				<redirect:write
					file="{$output.dir}/{$package.dir}/{@id}_{@name}-fails.html">
					<xsl:apply-templates select="." mode="class.details">
						<xsl:with-param name="type" select="'fails'" />
					</xsl:apply-templates>
				</redirect:write>
			</xsl:if>
			<xsl:if test="@errors != 0">
				<redirect:write
					file="{$output.dir}/{$package.dir}/{@id}_{@name}-errors.html">
					<xsl:apply-templates select="." mode="class.details">
						<xsl:with-param name="type" select="'errors'" />
					</xsl:apply-templates>
				</redirect:write>
			</xsl:if>
		</xsl:for-each>
	</xsl:template>

	<xsl:template name="index.html">
		<html>
			<head>
				<title>
					<xsl:value-of select="$PRODUCT" />
					•
					<xsl:value-of select="$TITLE" />
				</title>
			</head>
			<frameset cols="20%,80%">
				<frameset rows="30%,70%">
					<frame src="overview-frame.html" name="packageListFrame" />
					<frame src="allclasses-frame.html" name="classListFrame" />
				</frameset>
				<frame src="overview-summary.html" name="classFrame" />
				<noframes>
					<h2>Frame Alert</h2>
					<p class="note">
						This document is designed to be viewed using the frames
						feature. If
						you see this message, you are using a non-frame-capable
						web
						client.
					</p>
				</noframes>
			</frameset>
		</html>
	</xsl:template>

	<!-- this is the stylesheet css to use for nearly everything -->
	<xsl:template name="stylesheet.css">
&style;
	</xsl:template>

	<!-- Create list of all/failed/errored tests -->
	<xsl:template match="testsuites" mode="all.tests">
		<xsl:param name="type" select="'all'" />
		<html class="report">
			<xsl:variable name="title">
				<xsl:choose>
					<xsl:when test="$type = 'fails'">
						<xsl:text>All Failures</xsl:text>
					</xsl:when>
					<xsl:when test="$type = 'errors'">
						<xsl:text>All Errors</xsl:text>
					</xsl:when>
					<xsl:when test="$type = 'ignored'">
						<xsl:text>All Ignored</xsl:text>
					</xsl:when>
					<xsl:when test="$type = 'triedAgain'">
						<xsl:text>All Tried Again</xsl:text>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text>All Tests</xsl:text>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:variable>
			<head>
				<title>
					Unit Test Results:
					<xsl:value-of select="$title" />
				</title>
				<xsl:call-template name="create.stylesheet.link">
					<xsl:with-param name="package.name" />
				</xsl:call-template>
			</head>
			<body class="report-body">
				<xsl:attribute name="onload">open('allclasses-frame.html','classListFrame')</xsl:attribute>
				<h2>
					<xsl:value-of select="$title" />
				</h2>

				<table class="details">
					<xsl:call-template name="testcase.test.header">
						<xsl:with-param name="show.class" select="'yes'" />
					</xsl:call-template>
					<!-- test can even not be started at all (failure to load the class) 
						so report the error directly -->
					<xsl:if test="./error">
						<tr>
							<td class="status error" colspan="4">
								<xsl:apply-templates select="./error" />
							</td>
						</tr>
					</xsl:if>
					<xsl:choose>
						<xsl:when test="$type = 'fails'">
							<xsl:apply-templates select=".//testsuite[@ignored='0']/testcase[failure]"
								mode="print.test">
								<xsl:with-param name="show.class" select="'yes'" />
							</xsl:apply-templates>
						</xsl:when>
						<xsl:when test="$type = 'errors'">
							<xsl:apply-templates select=".//testsuite[@ignored='0']/testcase[error]"
								mode="print.test">
								<xsl:with-param name="show.class" select="'yes'" />
							</xsl:apply-templates>
						</xsl:when>
						<xsl:when test="$type = 'ignored'">
							<xsl:apply-templates select=".//testsuite[@ignored='1']/testcase"
								mode="print.test">
								<xsl:with-param name="show.class" select="'yes'" />
							</xsl:apply-templates>
						</xsl:when>
						<xsl:when test="$type = 'triedAgain'">
							<xsl:apply-templates select=".//testsuite[@triedAgain='1']/testcase"
								mode="print.test">
								<xsl:with-param name="show.class" select="'yes'" />
							</xsl:apply-templates>
						</xsl:when>
						<xsl:otherwise>
							<xsl:apply-templates select=".//testcase"
								mode="print.test">
								<xsl:with-param name="show.class" select="'yes'" />
							</xsl:apply-templates>
						</xsl:otherwise>
					</xsl:choose>
				</table>
			</body>
		</html>
	</xsl:template>


	<!-- ====================================================================== 
		This page is created for every testsuite class. It prints a summary of the 
		testsuite and detailed information about testcase methods. ====================================================================== -->
	<xsl:template match="testsuite" mode="class.details">
		<xsl:param name="type" select="'all'" />
		<xsl:variable name="package.name" select="@package" />
		<xsl:variable name="class.name">
			<xsl:if test="not($package.name = '')">
				<xsl:value-of select="$package.name" />
				.
			</xsl:if>
			<xsl:value-of select="@name" />
		</xsl:variable>
		<html class="report">
			<head>
				<title>
					Unit Test Results:
					<xsl:value-of select="$class.name" />
				</title>
				<xsl:call-template name="create.stylesheet.link">
					<xsl:with-param name="package.name" select="$package.name" />
				</xsl:call-template>
			</head>
			<body class="report-body">
				<h3>
					Class
					<code>
						<xsl:value-of select="$class.name" />
					</code>
				</h3>

				<table class="details">
					<xsl:call-template name="testsuite.test.header" />
					<xsl:apply-templates select="." mode="print.test" />
				</table>

				<xsl:choose>
					<xsl:when test="$type = 'fails'">
						<h2>Failures</h2>
					</xsl:when>
					<xsl:when test="$type = 'errors'">
						<h2>Errors</h2>
					</xsl:when>
					<xsl:when test="$type = 'ignored'">
						<h2>Ignored</h2>
					</xsl:when>
					<xsl:when test="$type = 'triedAgain'">
						<h2>Tried Again</h2>
					</xsl:when>
					<xsl:otherwise>
						<h2>Tests</h2>
					</xsl:otherwise>
				</xsl:choose>
				<table class="details">
					<xsl:call-template name="testcase.test.header" />
					<!-- test can even not be started at all (failure to load the class) 
						so report the error directly -->
					<xsl:if test="./error">
						<tr>
							<td class="status error" colspan="4">
								<xsl:apply-templates select="./error" />
							</td>
						</tr>
					</xsl:if>
					<xsl:choose>
						<xsl:when test="$type = 'fails'">
							<xsl:apply-templates select="./testcase[failure]"
								mode="print.test" />
						</xsl:when>
						<xsl:when test="$type = 'errors'">
							<xsl:apply-templates select="./testcase[error]"
								mode="print.test" />
						</xsl:when>
						<xsl:when test="$type = 'ignored'">
							<xsl:apply-templates select="./testcase"
								mode="print.test" />
						</xsl:when>
						<xsl:when test="$type = 'triedAgain'">
							<xsl:apply-templates select="./testcase"
								mode="print.test" />
						</xsl:when>
						<xsl:otherwise>
							<xsl:apply-templates select="./testcase"
								mode="print.test" />
						</xsl:otherwise>
					</xsl:choose>
				</table>
			</body>
		</html>
	</xsl:template>

	<!-- ====================================================================== 
		This page is created for every package. It prints the name of all classes 
		that belongs to this package. @param name the package name to print classes. 
		====================================================================== -->
	<!-- list of classes in a package -->
	<xsl:template name="classes.list">
		<xsl:param name="name" />
		<html>
			<head>
				<title>
					Unit Test Classes:
					<xsl:value-of select="$name" />
				</title>
				<xsl:call-template name="create.stylesheet.link">
					<xsl:with-param name="package.name" select="$name" />
				</xsl:call-template>
			</head>
			<body>
				<h2>
					<a href="package-summary.html" target="classFrame">
						<code>
							<xsl:value-of select="$name" />
						</code>
						<xsl:if test="$name = ''">
							&lt;none&gt;
						</xsl:if>
					</a>
				</h2>

				<h2>Classes</h2>
				<ul>
					<xsl:for-each select="/testsuites/testsuite[./@package = $name]">
						<xsl:sort select="@name" />
						<li nowrap="nowrap">
							<a href="{@id}_{@name}.html" target="classFrame">
								<code>
									<xsl:value-of select="@name" />
								</code>
							</a>
						</li>
					</xsl:for-each>
				</ul>
			</body>
		</html>
	</xsl:template>


	<!-- Creates an all-classes.html file that contains a link to all package-summary.html 
		on each class. -->
	<xsl:template match="testsuites" mode="all.classes">
		<html>
			<head>
				<title>All Unit Test Classes</title>
				<xsl:call-template name="create.stylesheet.link">
					<xsl:with-param name="package.name" />
				</xsl:call-template>
			</head>
			<body>
				<h2>Classes</h2>
				<ul>
					<xsl:apply-templates select="testsuite" mode="all.classes">
						<xsl:sort select="@name" />
					</xsl:apply-templates>
				</ul>
			</body>
		</html>
	</xsl:template>

	<xsl:template match="testsuite" mode="all.classes">
		<xsl:variable name="package.name" select="@package" />
		<li>
			<a target="classFrame">
				<xsl:attribute name="href">
                    <xsl:if test="not($package.name='')">
                        <xsl:value-of
					select="translate($package.name,'.','/')" /><xsl:text>/</xsl:text>
                    </xsl:if><xsl:value-of select="@id" />_<xsl:value-of
					select="@name" /><xsl:text>.html</xsl:text>
                </xsl:attribute>
				<code>
					<xsl:value-of select="@name" />
				</code>
			</a>
		</li>
	</xsl:template>


	<!-- Creates an html file that contains a link to all package-summary.html 
		files on each package existing on testsuites. @bug there will be a problem 
		here, I don't know yet how to handle unnamed package :( -->
	<xsl:template match="testsuites" mode="all.packages">
		<html>
			<head>
				<title>All Unit Test Packages</title>
				<xsl:call-template name="create.stylesheet.link">
					<xsl:with-param name="package.name" />
				</xsl:call-template>
			</head>
			<body>
				<h1>
					<a href="overview-summary.html" target="classFrame">
						<xsl:value-of select="$PRODUCT" />
					</a>
				</h1>
				<h2>Packages</h2>
				<ul>
					<xsl:apply-templates
						select="testsuite[not(./@package = preceding-sibling::testsuite/@package)]"
						mode="all.packages">
						<xsl:sort select="@package" />
					</xsl:apply-templates>
				</ul>
			</body>
		</html>
	</xsl:template>

	<xsl:template match="testsuite" mode="all.packages">
		<li>
			<a href="./{translate(@package,'.','/')}/package-summary.html"
				target="classFrame">
				<code>
					<xsl:value-of select="@package" />
				</code>
				<xsl:if test="@package = ''">
					&lt;none&gt;
				</xsl:if>
			</a>
		</li>
	</xsl:template>


	<xsl:template match="testsuites" mode="overview.packages">
		<html class="report">
			<head>
				<title>Unit Test Results: Summary</title>
				<xsl:call-template name="create.stylesheet.link">
					<xsl:with-param name="package.name" />
				</xsl:call-template>
			</head>
			<body class="report-body">
				<xsl:attribute name="onload">open('allclasses-frame.html','classListFrame')</xsl:attribute>
				<h2>Summary</h2>
				<xsl:variable name="testCount" select="sum(testsuite/@tests)" />
				<xsl:variable name="errorCount" select="sum(testsuite/@errors)" />
				<xsl:variable name="failureCount" select="sum(testsuite/@failures)" />
				<xsl:variable name="timeCount" select="sum(testsuite/@time)" />
				<xsl:variable name="ignoredCount" select="sum(testsuite/@ignored)" />
				<xsl:variable name="triedAgainCount" select="sum(testsuite/@triedAgain)" />
				<xsl:variable name="successRate" select="($testCount - $failureCount - $errorCount - $ignoredCount) div ($testCount - $ignoredCount)"/>
				<xsl:variable name="assertsOkCount"
					select="sum(testsuite[@ignored='0']/@asserts_ok)" />
				<xsl:variable name="assertsNokCount"
					select="sum(testsuite[@ignored='0']/@asserts_nok)" />
				<xsl:variable name="assertsCount" select="$assertsOkCount + $assertsNokCount" />
				<xsl:variable name="assertsSuccessRate"
					select="($assertsCount - $assertsNokCount) div $assertsCount" />
				<table class="details">
					<tr>
						<th>Tests</th>
						<th>Failures</th>
						<th>Errors</th>
						<th>Ignored</th>
						<th>Tried Again</th>
						<th>Success rate</th>
						<th>Time</th>
					</tr>
					<tr>
						<td>
							<a title="Display all tests" href="all-tests.html">
								<xsl:value-of select="$testCount" />
							</a>
						</td>
						<td>
							<xsl:attribute name="class">
                <xsl:if test="$failureCount &gt; 0">status failure</xsl:if>
            </xsl:attribute>
							<a title="Display all failures" href="alltests-fails.html">
								<xsl:value-of select="$failureCount" />
							</a>
						</td>
						<td>
							<xsl:attribute name="class">
                <xsl:if test="$errorCount &gt; 0">status error</xsl:if>
            </xsl:attribute>
							<a title="Display all errors" href="alltests-errors.html">
								<xsl:value-of select="$errorCount" />
							</a>
						</td>
						<td>
							<xsl:attribute name="class">
                 <xsl:if test="$ignoredCount &gt; 0">status ignored</xsl:if>
            </xsl:attribute>
							<a title="Display all ignored" href="alltests-ignored.html">
								<xsl:value-of select="$ignoredCount" />
							</a>
						</td>
						<td>
							<xsl:attribute name="class">
                 <xsl:if test="$triedAgainCount &gt; 0">status triedAgain</xsl:if>
            </xsl:attribute>
							<a title="Display all tried again" href="alltests-triedAgain.html">
								<xsl:value-of select="$triedAgainCount" />
							</a>
						</td>
						<td>
							<xsl:attribute name="class">
	                <xsl:if test="$successRate = 1">status success</xsl:if>
	            </xsl:attribute>
							<xsl:call-template name="display-percent">
								<xsl:with-param name="value" select="$successRate" />
							</xsl:call-template>
						</td>
						<td>
							<xsl:call-template name="display-time">
								<xsl:with-param name="value" select="$timeCount" />
							</xsl:call-template>
						</td>
					</tr>
				</table>

				<table class="details">
					<thead>
						<tr>
							<th>Assertions</th>
							<th>Failures</th>
							<th>Success</th>
							<th>Success Rate</th>
						</tr>
					</thead>
					<tr>
						<td>
							<xsl:value-of select="$assertsCount" />
						</td>
						<td>
							<xsl:attribute name="class">
                <xsl:if test="$assertsNokCount &gt; 0">status failure</xsl:if>
            </xsl:attribute>
							<xsl:value-of select="$assertsNokCount" />
						</td>
						<td>
							<xsl:value-of select="$assertsOkCount" />
						</td>
						<td>
							<xsl:attribute name="class">
	                <xsl:if test="$assertsSuccessRate = 1">status success</xsl:if>
	            </xsl:attribute>
							<xsl:call-template name="display-percent">
								<xsl:with-param name="value" select="$assertsSuccessRate" />
							</xsl:call-template>
						</td>
					</tr>
				</table>

				<p class="note">
					Note:
					<em class="status failure">failures</em>
					are anticipated and checked for with assertions while
					<em class="status error">errors</em>
					are unanticipated.
				</p>
				<p class="note">
					Note:
					<em class="status ignored">ignored</em>
					tests are executed but not counted on the success rate.
				</p>
				<p class="note">
					Note: 
					<em class="status triedAgain">tried again</em> 
					tests are executed but not counted on the success rate.
				</p>

				<h2>Packages</h2>
				<table class="details">
					<xsl:call-template name="testsuite.test.header" />
					<xsl:for-each
						select="testsuite[not(./@package = preceding-sibling::testsuite/@package)]">
						<xsl:sort select="@package" order="ascending" />
						<!-- get the node set containing all testsuites that have the same 
							package -->
						<xsl:variable name="insamepackage"
							select="/testsuites/testsuite[./@package = current()/@package]" />
						<tr>
							<td>
								<a href="./{translate(@package,'.','/')}/package-summary.html">
									<code>
										<xsl:value-of select="@package" />
									</code>
									<xsl:if test="@package = ''">
										&lt;none&gt;
									</xsl:if>
								</a>
							</td>
							<td>
								<xsl:value-of select="sum($insamepackage/@tests)" />
							</td>
							<td>
								<xsl:attribute name="class">
                <xsl:if test="sum($insamepackage/@errors) &gt; 0">status error</xsl:if>
            </xsl:attribute>
								<xsl:value-of select="sum($insamepackage/@errors)" />
							</td>
							<td>
								<xsl:attribute name="class">
                <xsl:if test="sum($insamepackage/@failures) &gt; 0">status failure</xsl:if>
            </xsl:attribute>
								<xsl:value-of select="sum($insamepackage/@failures)" />
							</td>
							<td>
								<xsl:attribute name="class">
                <xsl:if test="sum($insamepackage/@ignored) &gt; 0">status ignored</xsl:if>
            </xsl:attribute>
								<xsl:value-of select="sum($insamepackage/@ignored)" />
							</td>
							<td>
								<xsl:attribute name="class">
                <xsl:if test="sum($insamepackage/@triedAgain) &gt; 0">status triedAgain</xsl:if>
            </xsl:attribute>
								<xsl:value-of select="sum($insamepackage/@triedAgain)" />
							</td>
							<td>
								<xsl:call-template name="display-time">
									<xsl:with-param name="value" select="sum($insamepackage/@time)" />
								</xsl:call-template>
							</td>
							<td>
								<xsl:value-of select="$insamepackage/@timestamp" />
							</td>
							<td>
								<xsl:value-of select="$insamepackage/@hostname" />
							</td>
						</tr>
					</xsl:for-each>
				</table>
			</body>
		</html>
	</xsl:template>


	<xsl:template name="package.summary">
		<xsl:param name="name" />
		<html class="report">
			<head>
				<xsl:call-template name="create.stylesheet.link">
					<xsl:with-param name="package.name" select="$name" />
				</xsl:call-template>
			</head>
			<body class="report-body">
				<xsl:attribute name="onload">open('package-frame.html','classListFrame')</xsl:attribute>
				<h3>
					Package
					<code>
						<xsl:value-of select="$name" />
					</code>
				</h3>

				<xsl:variable name="insamepackage"
					select="/testsuites/testsuite[./@package = $name]" />
				<xsl:if test="count($insamepackage) &gt; 0">
					<h2>Classes</h2>
					<table class="details">
						<xsl:call-template name="testsuite.test.header" />
						<xsl:apply-templates select="$insamepackage"
							mode="print.test">
							<xsl:sort select="@name" />
						</xsl:apply-templates>
					</table>
				</xsl:if>
			</body>
		</html>
	</xsl:template>


	<!-- transform string like a.b.c to ../../../ @param path the path to transform 
		into a descending directory path -->
	<xsl:template name="path">
		<xsl:param name="path" />
		<xsl:if test="contains($path,'.')">
			<xsl:text>../</xsl:text>
			<xsl:call-template name="path">
				<xsl:with-param name="path">
					<xsl:value-of select="substring-after($path,'.')" />
				</xsl:with-param>
			</xsl:call-template>
		</xsl:if>
		<xsl:if test="not(contains($path,'.')) and not($path = '')">
			<xsl:text>../</xsl:text>
		</xsl:if>
	</xsl:template>

	<!-- create the link to the stylesheet based on the package name -->
	<xsl:template name="create.stylesheet.link">
		<xsl:param name="package.name" />
		<link rel="stylesheet" type="text/css" title="Style">
			<xsl:attribute name="href"><xsl:if
				test="not($package.name = 'unnamed package')"><xsl:call-template name="path"><xsl:with-param
				name="path" select="$package.name" /></xsl:call-template></xsl:if>stylesheet.css</xsl:attribute>
		</link>
	</xsl:template>

	<!-- class header -->
	<xsl:template name="testsuite.test.header">
		<tr>
			<th width="70%">Name</th>
			<th>Tests</th>
			<th>Errors</th>
			<th>Failures</th>
			<th>Ignored</th>
			<th>Tried Again</th>
			<th nowrap="nowrap">Time(s)</th>
			<th nowrap="nowrap">Time Stamp</th>
			<th>Host</th>
		</tr>
	</xsl:template>

	<!-- method header -->
	<xsl:template name="testcase.test.header">
		<xsl:param name="show.class" select="''" />
		<tr valign="top">
			<xsl:if test="boolean($show.class)">
				<th>Class</th>
			</xsl:if>
			<th>Name</th>
			<th>Status</th>
			<th width="80%">Type</th>
			<th nowrap="nowrap">Time(s)</th>
		</tr>
	</xsl:template>


	<!-- class information -->
	<xsl:template match="testsuite" mode="print.test">
		<tr>
			<td>
				<a title="Display all tests" href="{@id}_{@name}.html">
					<code>
						<xsl:value-of select="@name" />
					</code>
				</a>
			</td>
			<td>
				<a title="Display all tests" href="{@id}_{@name}.html">
					<code>
						<xsl:apply-templates select="@tests" />
					</code>
				</a>
			</td>
			<td>
				<xsl:attribute name="class">
                <xsl:if test="@errors &gt; 0">status error</xsl:if>
            </xsl:attribute>
				<xsl:choose>
					<xsl:when test="@errors != 0">
						<a title="Display only errors" href="{@id}_{@name}-errors.html">
							<xsl:apply-templates select="@errors" />
						</a>
					</xsl:when>
					<xsl:otherwise>
						<xsl:apply-templates select="@errors" />
					</xsl:otherwise>
				</xsl:choose>
			</td>
			<td>
				<xsl:attribute name="class">
                <xsl:if test="@failures &gt; 0">status failure</xsl:if>
            </xsl:attribute>
				<xsl:choose>
					<xsl:when test="@failures != 0">
						<a title="Display only failures" href="{@id}_{@name}-fails.html">
							<xsl:apply-templates select="@failures" />
						</a>
					</xsl:when>
					<xsl:otherwise>
						<xsl:apply-templates select="@failures" />
					</xsl:otherwise>
				</xsl:choose>
				<td>
					<xsl:attribute name="class">
                		<xsl:if test="@ignored &gt; 0">status ignored</xsl:if>
            		</xsl:attribute>
					<xsl:apply-templates select="@ignored" />
				</td>
				<td>
					<xsl:attribute name="class">
                		<xsl:if test="@triedAgain &gt; 0">status triedAgain</xsl:if>
            		</xsl:attribute>
					<xsl:apply-templates select="@triedAgain" />
				</td>
			</td>
			<td>
				<xsl:call-template name="display-time">
					<xsl:with-param name="value" select="@time" />
				</xsl:call-template>
			</td>
			<td>
				<xsl:apply-templates select="@timestamp" />
			</td>
			<td>
				<xsl:apply-templates select="@hostname" />
			</td>
		</tr>
	</xsl:template>

	<xsl:template match="testcase" mode="print.test">
		<xsl:param name="show.class" select="''" />
		<tr>
			<xsl:variable name="class.href">
				<xsl:value-of
					select="concat(translate(../@package,'.','/'), '/', ../@id, '_', ../@name, '.html')" />
			</xsl:variable>
			<xsl:if test="boolean($show.class)">
				<td>
					<a href="{$class.href}">
						<code>
							<xsl:value-of select="../@name" />
						</code>
					</a>
				</td>
			</xsl:if>
			<td id="{@name}">
				<xsl:choose>
					<xsl:when test="boolean($show.class)">
						<a href="{concat($class.href, '#', @name)}">
							<code>
								<xsl:value-of select="@name" />
							</code>
						</a>
					</xsl:when>
					<xsl:otherwise>
						<code>
							<xsl:value-of select="@name" />
						</code>
					</xsl:otherwise>
				</xsl:choose>
			</td>
			<xsl:choose>
				<xsl:when test="(../@ignored!=0) and (failure)">
					<td class="status ignored">Ignored (Failure)</td>
					<td>
						<xsl:apply-templates select="failure" />
					</td>
				</xsl:when>
				<xsl:when test="(../@ignored!=0) and (error)">
					<td class="status ignored">Ignored (Error)</td>
					<td>
						<xsl:apply-templates select="error" />
					</td>
				</xsl:when>
				<xsl:when test="(../@ignored!=0)">
					<td class="status ignored">Ignored (Success)</td>
					<td>
						<xsl:apply-templates select="system-out" />
					</td>
				</xsl:when>
				<xsl:when test="(../@triedAgain!=0) and (failure)">
	    	         <td class="status triedAgain">Tried Again Later (Failure)</td>
	                <td><xsl:apply-templates select="failure"/></td>
	            </xsl:when>
	        	<xsl:when test="(../@triedAgain!=0) and (error)">
	    	         <td class="status triedAgain">Tried Again Later (Error)</td>
	                <td><xsl:apply-templates select="error"/></td>
	            </xsl:when>
	            <xsl:when test="(../@triedAgain!=0)">
	    	         <td class="status triedAgain">Tried Again Later (Success)</td>
	                <td><xsl:apply-templates select="system-out"/></td>
	            </xsl:when>
				<xsl:when test="failure">
					<td class="status failure">Failure</td>
					<td>
						<xsl:apply-templates select="failure" />
					</td>
				</xsl:when>
				<xsl:when test="error">
					<td class="status error">Error</td>
					<td>
						<xsl:apply-templates select="error" />
					</td>
				</xsl:when>
				<xsl:otherwise>
					<td class="status success">Success</td>
					<td>
						<xsl:apply-templates select="system-out" />
					</td>
				</xsl:otherwise>
			</xsl:choose>
			<td>
				<xsl:call-template name="display-time">
					<xsl:with-param name="value" select="@time" />
				</xsl:call-template>
			</td>
		</tr>
	</xsl:template>


	<!-- Note : the below template error and failure are the same style so just 
		call the same style store in the toolkit template -->
	<xsl:template match="failure">
		<xsl:call-template name="display-failures" />
	</xsl:template>

	<xsl:template match="error">
		<xsl:call-template name="display-failures" />
	</xsl:template>

	<xsl:template match="system-out">
		<xsl:call-template name="display-failures" />
	</xsl:template>

	<!-- Style for the error and failure in the testcase template -->
	<xsl:template name="display-failures">
		<xsl:choose>
			<xsl:when test="not(@message)">
				N/A
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="@message" />
			</xsl:otherwise>
		</xsl:choose>
		<!-- display the stacktrace -->
		<pre>
			<code>
				<xsl:value-of select="." />
			</code>
		</pre>
	</xsl:template>

	<xsl:template name="display-time">
		<xsl:param name="value" />
		<xsl:value-of select="format-number($value,'0.000')" />
	</xsl:template>

	<xsl:template name="display-percent">
		<xsl:param name="value" />
		<xsl:value-of select="format-number($value,'0.00%')" />
	</xsl:template>
</xsl:stylesheet>
