/*
 * Java
 *
 * Copyright 2008-2020 IS2T. All rights reserved.
 * IS2T PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */ 
package com.is2t.vm.support.io;

import java.io.IOException;
import java.io.InputStream;

/**
 * VM known class used to access to raw memory as a stream
 */
public class MemoryInputStream extends InputStream
{
    int startAddress; //VM known
    int endAddress;//exclusive   //VM known
    int currentPtr;   //VM known
    int markPtr;      //VM known
    
    /**
    *  Create a new MemoryInputStream whose mapped the memories
    *  addresses : [startAdress,  startAdress+ length[
    * 
     * @param startAddress start address of the stream in the memory
     * @param length data length
     */
    public MemoryInputStream(int startAddress, int length)
    {
        this.startAddress = this.markPtr = this.currentPtr = startAddress;
        this.endAddress = startAddress+length;
    }

   /**
    * return the number of available address in the MemoryInputStream
    */
    public int available() throws IOException
    {
        return endAddress - currentPtr;
    }
    
    public boolean markSupported()
    {
        return true;
    }

    public void mark(int readlimit)
    {
        markPtr = currentPtr;
    }

    public void reset() throws IOException
    {
        currentPtr = markPtr;
    }

    public int read(byte[] b) throws IOException
    {
        return readArray(b, 0, b.length);
    }

    public long skip(long n) throws IOException
    {
    	int oldPtr =  currentPtr;
        int available = endAddress - oldPtr;
        
        if(n > available) {
        	n = available;
        }
        
        int newPtr = oldPtr + (int)n;
        if(newPtr < startAddress){
        	// n was negative and we skipped back to many bytes.
        	newPtr = startAddress;
        }
        
        this.currentPtr = newPtr;
        
        return newPtr - oldPtr;
    }
    
    public int read(byte[] b, int off, int len) throws IOException
    {
    	return readArray(b, off, len);
    }

    public native int read() throws IOException;
    public native int readArray(byte[] b, int off, int len) throws IOException;
    
}
