/*
 * Java
 *
 * Copyright 2020 MicroEJ Corp.
 * This software has been designed or modified by MicroEJ Corp.
 * MicroEJ Corp. grants to THALES the non-exclusive right to freely use, modify and distribute this software.
 */
package demo.mqtt;

import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.util.Properties;

public abstract class DemoProperties {

	private static final String DEMO_PROPERTIES_PATH = "demo.properties.path";

	public static final String BROKER_URL = "broker.url";
	public static final String BROKER_CERTIFICATE = "broker.certificate";
	public static final String BROKER_USERNAME = "broker.username";
	public static final String BROKER_PASSWORD = "broker.password"; // NOSONAR

	public static final String SIM_PIN = "sim.pin";
	public static final String SIM_APN = "sim.apn";
	public static final String SIM_USERNAME = "sim.username";
	public static final String SIM_PASSWORD = "sim.password"; // NOSONAR

	public static final String MQTT_TOPIC = "mqtt.topic";
	public static final String SKIP_GNSS = "skip.gnss";

	private static final Properties PROPERTIES = loadProperties();

	private DemoProperties() {
		// Instantiation forbidden
	}

	public static String getProperty(String propertyName) {
		String propertyValue;

		propertyValue = PROPERTIES.getProperty(propertyName);

		if (propertyValue == null) {
			propertyValue = System.getProperty(propertyName);
		}

		return propertyValue;
	}

	private static Properties loadProperties() {
		Properties properties = new Properties();
		String path = System.getProperty(DEMO_PROPERTIES_PATH);
		try (InputStream inputStream = new FileInputStream(path)) {
			properties.load(inputStream);
		} catch (IOException e) {
			e.printStackTrace();
		}
		return properties;
	}

}
