package com.cwm.util;

public class GPRSConnectOptions {
    private static GPRSConnectOptions instance;
    private static String connParamsSocket = null;   // APN, username and password;
    private String bearer_type = "";
    private String access_point = "";
    private String username = "";
    private String passwd = "";
    private int timeout = 60;

    public static GPRSConnectOptions getInstance() {
        if (instance == null) {
            instance = new GPRSConnectOptions();
        }
        return instance;
    }

    public boolean setConnectionParameters(String connParamsIn) {
        final boolean DEBUG = false;
        boolean retVal = false;
        int start;
        int end;

        if (connParamsIn != null) {
            connParamsSocket = connParamsIn;
        } else {
            connParamsSocket = null;
        }

        if (connParamsSocket != null) {
            try {
                if (connParamsSocket.toUpperCase().indexOf(";ACCESS_POINT=") > -1) {
                    start = connParamsSocket.toUpperCase().indexOf(";ACCESS_POINT=") + ";ACCESS_POINT=".length();
                    if (start != -1) {
                        end = connParamsSocket.toUpperCase().indexOf(";", start);
                        if (end != -1) {
                            setAPN(connParamsSocket.substring(start, end));
                            if (DEBUG) {System.out.println("[GPRSConnectOptions]: setAPN = '" + connParamsSocket.substring(start, end) + "' s=" + start + ", e=" + end);}
                        }
                    }
                }
                if (connParamsSocket.toUpperCase().indexOf(";USERNAME=") > -1) {
                    start = connParamsSocket.toUpperCase().indexOf(";USERNAME=") + ";USERNAME=".length();
                    if (start != -1) {
                        end = connParamsSocket.toUpperCase().indexOf(";", start);
                        if (end != -1) {
                            setUser(connParamsSocket.substring(start, end));
                            if (DEBUG) {System.out.println("[GPRSConnectOptions]: setUser = '" + connParamsSocket.substring(start, end) + "' s=" + start + ", e=" + end);}
                        }
                    }
                }
                if (connParamsSocket.toUpperCase().indexOf(";PASSWORD=") > -1) {
                    start = connParamsSocket.toUpperCase().indexOf(";PASSWORD=") + ";PASSWORD=".length();
                    if (start != -1) {
                        end = connParamsSocket.toUpperCase().indexOf(";", start);
                        if (end != -1) {
                            setPasswd(connParamsSocket.substring(start, end));
                            if (DEBUG) {System.out.println("[GPRSConnectOptions]: setPasswd = '" + connParamsSocket.substring(start, end) + "' s=" + start + ", e=" + end);}
                        }
                    }
                }
                if (connParamsSocket.toUpperCase().indexOf(";TIMEOUT=") > -1) {
                    start = connParamsSocket.toUpperCase().indexOf(";TIMEOUT=") + ";TIMEOUT=".length();
                    if (start != -1) {
                        end = connParamsSocket.toUpperCase().indexOf(";", start);
                        if (end != -1) {
                            setTimeout(connParamsSocket.substring(start, end));
                            if (DEBUG) {System.out.println("[GPRSConnectOptions]: setTimeout = '" + connParamsSocket.substring(start, end) + "' s=" + start + ", e=" + end);}
                        } else {
                            setTimeout(connParamsSocket.substring(start));                        
                            if (DEBUG) {System.out.println("[GPRSConnectOptions]: setTimeout = '" + connParamsSocket.substring(start) + "' s=" + start);}
                        }
                    }
                }
            } catch (Exception e) {
                System.out.println("[GPRSConnectOptions]: Warning: setConnectionParameters() - ");
            }
        } else {
            System.out.println("[GPRSConnectOptions]: setConnectionParameters() called with null parameter.");
        }
        
        return retVal;
    }

    public void setBearerType(String bt) {
        bearer_type = bt;
    }

    public void setAPN(String apn) {
        access_point = apn;
    }

    public void setTimeout(int time) {
        timeout = time;
    }

    public void setTimeout(String timeIn) {
        if (timeIn != null) {
            try {
                timeout = Integer.parseInt(timeIn.trim());
            } catch (Exception e) {
                System.out.println("[GPRSConnectOptions]: Warning: setTimeout() - " + e.toString());
            }
            
            if ((timeout < 10) || (timeout > 300)) {
                timeout = 30;
                System.out.println("[GPRSConnectOptions]: Warning: setTimeout() Invalid timeIn value.");
            }
        }
    }
    
    public void setUser(String usr) {
        this.username = usr;
    }

    public void setPasswd(String pwd) {
        this.passwd = pwd;
    }
    
    public String getBearerType() {
        return bearer_type;
    }

    public String getConnParamsSocket() {
        return connParamsSocket;
    }

    public String getAPN() {
        return access_point;
    }

    public int getTimeout(){
        return timeout;
    }
    
    public String getUser() {
        return username;
    }

    public String getPasswd() {
        return passwd;
    }
}
