/**
 * Java
 *
 * Copyright 2011-2020 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.ecom.mobile.natives;

/**
 * Class for the native AT methods declarations.
 */
public class NativeAT {

	private NativeAT() {
		// Private constructor to hide the implicit one.
	}

	/**
	 * Send data over the AT connection.
	 *
	 * @param data
	 *            Buffer of data to send.
	 * @param length
	 *            Length of the buffer.
	 * @return A negative value if the data failed to be sent.
	 */
	public static native int sendData(byte[] data, int length);

	/**
	 * Read data from the AT connection.
	 *
	 * @param data
	 *            Destination buffer for the received data.
	 * @param length
	 *            Length of the data to read.
	 * @return The length of data read, otherwise a negative value.
	 */
	public static native int readData(byte[] data, int length);

	/**
	 * Wait for data on the AT connection.
	 */
	public static native void waitForData();
}
