/**
 * Java
 *
 * Copyright 2012-2020 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.ecom.mobile.natives;

/**
 * Class for the native PDP methods declarations.
 */
public class NativePDP {

	private NativePDP() {
		// Private constructor to hide the implicit one.
	}

	/**
	 * Activate a session with the given configuration in parameters.
	 *
	 * @param apn
	 *            Buffer for the APN.
	 * @param apnLength
	 *            Length of the APN buffer.
	 * @param login
	 *            Buffer for the login.
	 * @param loginLength
	 *            Length of the login buffer.
	 * @param pwd
	 *            Buffer for the secret.
	 * @param pwdLength
	 *            Length for the secret buffer.
	 * @return The ID of the session, a negative value otherwise.
	 */
	public static native int activate(byte[] apn, int apnLength, byte[] login, int loginLength, byte[] pwd,
			int pwdLength);

	/**
	 * Deactivate the session.
	 *
	 * @param id
	 *            The ID of the session to deactivate.
	 * @return A negative value if the session failed to be deactivated.
	 */
	public static native int deactivate(int id);

	/**
	 * Method that blocks until the session is deactivated.
	 *
	 * @param id
	 *            The ID of the session.
	 */
	public static native void waitDeactivation(int id);

	/**
	 * @return The APN maximum size.
	 */
	public static native int getAPNMaxSize();

	/**
	 * @return The login maximum size.
	 */
	public static native int getLoginMaxSize();

	/**
	 * @return The secret maximum size.
	 */
	public static native int getPwdMaxSize();

}
