/*
 * Copyright (c) 1997, 2013, Oracle and/or its affiliates. All rights reserved.
 * Copyright (C) 2015-2018, IS2T - EDC compliance and optimizations.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

package java.security.cert;

import javax.security.auth.x500.X500Principal;

import com.is2t.support.security.x509.X509CertImpl;

public abstract class X509Certificate extends Certificate
implements X509Extension {

	private static final long serialVersionUID = -2491127588187038216L;
	private X500Principal issuerX500Principal;
	private X500Principal subjectX500Principal;

	protected X509Certificate() {
		super("X.509");
	}

	/**
	 * Returns the issuer (issuer distinguished name) value from the certificate as an <code>X500Principal</code>.
	 * <p>
	 * It is recommended that subclasses override this method.
	 *
	 * @return an <code>X500Principal</code> representing the issuer distinguished name
	 * @since 1.4
	 */
	public X500Principal getIssuerX500Principal() {
		if (issuerX500Principal == null) {
			issuerX500Principal = X509CertImpl.getIssuerX500Principal(this);
		}
		return issuerX500Principal;
	}

	/**
	 * Returns the subject (subject distinguished name) value from the certificate as an <code>X500Principal</code>. If
	 * the subject value is empty, then the <code>getName()</code> method of the returned <code>X500Principal</code>
	 * object returns an empty string ("").
	 * <p>
	 * It is recommended that subclasses override this method.
	 *
	 * @return an <code>X500Principal</code> representing the subject distinguished name
	 * @since 1.4
	 */
	public X500Principal getSubjectX500Principal() {
		if (subjectX500Principal == null) {
			subjectX500Principal = X509CertImpl.getSubjectX500Principal(this);
		}
		return subjectX500Principal;
	}

}
