/*
 * C
 *
 * Copyright 2020 MicroEJ Corp.
 * This software has been designed or modified by MicroEJ Corp.
 * MicroEJ Corp. grants to THALES the non-exclusive right to freely use, modify and distribute this software.
 *
 */

#include "jvm_dump.h"
#include "gina.h"
#include "LLMJVM.h"

#ifdef __cplusplus
extern "C" {
#endif

/**
 * @brief Expiration function for the timer.
 * 
 * @param param Input of the function passed at timer creation.
 */
static void dump_timer_expiration(uint32_t param) {
    LLMJVM_dump();
}

/**
 * @brief Start the timer that will print the JVM dump.
 * 
 * @param time Time of expiration for the timer in ticks (1 ticks is 10 ms).
 */
void start_dump_timer(uint32_t time) {
    TX_TIMER* dump_timer;
	uint8_t status = 0;

	gina_uwlog_printf("%s: allocating timer object", __func__);
	status = txm_module_object_allocate((void*) &dump_timer, sizeof(TX_TIMER));
	if (TX_SUCCESS != status) {
		gina_uwlog_printf("%s: txm_module_object_allocate returned %d", __func__, status);
		return;
	}

	gina_uwlog_printf("%s: creating timer", __func__);
	status = tx_timer_create(dump_timer, "dump timer", dump_timer_expiration, 0, time, 0, TX_AUTO_ACTIVATE);
	if (TX_SUCCESS != status) {
		gina_uwlog_printf("%s: tx_timer_create returned %d", __func__, status);
		return;
	}
}

#ifdef __cplusplus
}
#endif
