/*
 * C
 *
 * Copyright 2020 MicroEJ Corp.
 * This software has been designed or modified by MicroEJ Corp.
 * MicroEJ Corp. grants to THALES the non-exclusive right to freely use, modify and distribute this software.
 *
 */

#include <stdint.h>
#include <microej_allocator.h>
#include "gina.h"
#include "qapi_timer.h"
#include "microej_main.h"
#include "jvm_dump.h"
#include "microej_allocator.h"
#include "tx_api.h"

#define MICROJVM_THREAD_STACK_SIZE (12 * 1024)
#define MICROJVM_THREAD_PRIORITY (200) // Must be greater than 182 and lower than 227

typedef struct cleanup_callback_t {
	gina_uwmod_cleanup_cb_fn callback;
	struct cleanup_callback_t *next;
} cleanup_callback_t;

// FIXME: CC0231G-50 Link issue with display
uint8_t __icetea___6bss_6microui_6display_6externalFontsHeap$$Base;
uint8_t __icetea___6bss_6microui_6display_6externalFontsHeap$$Limit;

static TX_THREAD* microjvm_thread_handle;
static uint8_t microjvm_thread_stack[MICROJVM_THREAD_STACK_SIZE];
static cleanup_callback_t *callbacks;

static void _dam_cleanup(void* data);

/**
 * @brief Thread definition for the MicroJVM startup.
 * 
 */
void microjvm_thread_function(uint32_t param) {
	microej_main();
}

/**
 * @brief Entry point for the embedded application.
 * 
 * @return int32_t 
 */
int32_t _dam_main(void) {
	uint8_t status = 0;

	gina_init();

	gina_uwlog_printf("DAM main");

	microej_allocator_initialize();

	/* Allocate the thread object */
	status = txm_module_object_allocate((void *) &microjvm_thread_handle, sizeof(TX_THREAD));
	if (TX_SUCCESS != status) {
		gina_uwlog_printf("ERROR: Thread allocation failed, status = 0x%x", status);
	}

	/* Setup cleanup callbacks */
	callbacks = microej_malloc(sizeof(cleanup_callback_t));
	callbacks->callback = NULL;
	callbacks->next = NULL;
	gina_uwmod_set_cleanup(_dam_cleanup, NULL);

	/* Create the thread */
	status = tx_thread_create(microjvm_thread_handle, "MICROJVM", microjvm_thread_function, 0, &microjvm_thread_stack,
			MICROJVM_THREAD_STACK_SIZE, MICROJVM_THREAD_PRIORITY, MICROJVM_THREAD_PRIORITY - 1, TX_NO_TIME_SLICE,
			TX_AUTO_START);
	if (TX_SUCCESS != status) {
		gina_uwlog_printf("ERROR: Thread creation failed, status = %d", status);
	}

	return 0;
}

static void _dam_cleanup(void* data) {
	gina_uwmod_cleanup_cb_fn callback;
	cleanup_callback_t *tmp;
	while ((callback = callbacks->callback) != NULL) {
		callback(data);
		tmp = callbacks->next;
		microej_free(callbacks);
		callbacks = tmp;
	}
	gina_cleanup();
}

/**
 * @brief Adds a callback to the cleanup handle. The callback will be called when the application is stopped.
 */
void add_cleanup_callback(gina_uwmod_cleanup_cb_fn callback) {
	cleanup_callback_t *cbs = microej_malloc(sizeof(cleanup_callback_t));
	if (cbs == NULL) {
		gina_uwlog_printf("%s: cleanup allocation failed", __func__);
		return;
	}
	cbs->callback = callback;
	cbs->next = callbacks;
	callbacks = cbs;
}
