/*
 * C
 *
 * Copyright 2020 MicroEJ Corp.
 * This software has been designed or modified by MicroEJ Corp.
 * MicroEJ Corp. grants to THALES the non-exclusive right to freely use, modify and distribute this software.
 *
 */

#ifndef  FS_CONFIGURATION_H
#define  FS_CONFIGURATION_H

/**
 * @file
 * @brief LLFS configuration.
 * @author MicroEJ Developer Team
 * @version 1.0.1
 * @date 30 January 2020
 */

#include "qapi_fs_types.h"

#ifdef __cplusplus
	extern "C" {
#endif

/*** Map POSIX flags with QAPI flags ***/
#define O_RDONLY    QAPI_FS_O_RDONLY_E
#define O_WRONLY    QAPI_FS_O_WRONLY_E
#define O_CREAT     QAPI_FS_O_CREAT_E
#define O_TRUNC     QAPI_FS_O_TRUNC_E
#define O_APPEND    QAPI_FS_O_APPEND_E
#define O_RDWR      QAPI_FS_O_RDWR_E
#define O_EXCL      QAPI_FS_O_EXCL_E

/*** Map POSIX modes with QAPI modes ***/
#define S_IRUSR     QAPI_FS_S_IRUSR_E
#define S_IWUSR     QAPI_FS_S_IWUSR_E
#define S_IRGRP     QAPI_FS_S_IRGRP_E
#define S_IWGRP     QAPI_FS_S_IWGRP_E
#define S_IROTH     QAPI_FS_S_IROTH_E
#define S_IWOTH     QAPI_FS_S_IWOTH_E
#define S_IRWXU     (QAPI_FS_S_IRUSR_E | QAPI_FS_S_IWUSR_E | QAPI_FS_S_IXUSR_E)
#define S_IRWXG     (QAPI_FS_S_IRGRP_E | QAPI_FS_S_IWGRP_E | QAPI_FS_S_IXGRP_E)
#define S_IRWXO     (QAPI_FS_S_IROTH_E | QAPI_FS_S_IWOTH_E | QAPI_FS_S_IXOTH_E)

#define SEEK_CUR    QAPI_FS_SEEK_CUR_E

typedef qapi_FS_Offset_t off_t;

/**
 * @brief Compatibility sanity check value.
 * This define value is checked in the implementation to validate that the version of this configuration
 * is compatible with the implementation.
 *
 * This value must not be changed by the user of the CCO.
 * This value must be incremented by the implementor of the CCO when a configuration define is added, deleted or modified.
 */
#define FS_CONFIGURATION_VERSION (1)

/**
 * @brief Number of workers dedicated to the FS in async_worker.
 */
#define FS_WORKER_JOB_COUNT (4)

/**
 * @brief Size of the waiting list for FS jobs in async_worker.
 */
#define FS_WAITING_LIST_SIZE (16)

/**
 * @brief Size of the FS stack in bytes.
 */
#define FS_WORKER_STACK_SIZE (1024)

/**
 * @brief Priority of the FS workers.
 */
#define FS_WORKER_PRIORITY (205)

/**
 * @brief Maximum path length.
 */
#define FS_PATH_LENGTH (256)

/**
 * @brief Size of the IO buffer in bytes.
 */
#define FS_IO_BUFFER_SIZE (2048)

/**
 * @brief Set this define to print debug traces.
 */
//#define	LLFS_DEBUG

#ifdef __cplusplus
	}
#endif


#endif // FS_CONFIGURATION_H
