/*
 * C
 *
 * Copyright 2020 MicroEJ Corp.
 * This software has been designed or modified by MicroEJ Corp.
 * MicroEJ Corp. grants to THALES the non-exclusive right to freely use, modify and distribute this software.
 *
 */

/**
 * @file
 * @brief LLNET_NETWORKADDRESS 2.1.0 implementation over BSD-like API.
 * @author MicroEJ Developer Team
 * @version 1.1.1
 * @date 7 February 2020
 */

#include <LLNET_NETWORKADDRESS_impl.h>

#include <stdio.h>
#include <string.h>
#include <unistd.h>
#include "LLNET_CONSTANTS.h"
#include "LLNET_ERRORS.h"
#include "LLNET_Common.h"

#ifdef __cplusplus
	extern "C" {
#endif

#define LOCALHOST_NAME ("localhost")

int32_t LLNET_NETWORKADDRESS_IMPL_getLocalHostnameNative(int8_t* result, int32_t length, uint8_t retry) {
	LLNET_DEBUG_TRACE("%s\n", __func__);
	strlcpy((char*)result, LOCALHOST_NAME, length);
	return 0;
}

int32_t LLNET_NETWORKADDRESS_IMPL_lookupInaddrAny(int8_t* result, int32_t length, uint8_t retry)
{
	LLNET_DEBUG_TRACE("%s\n", __func__);

// If IPv6 or IPv4+IPv6 configuration, then use IPv6. Otherwise (only IPv4 configuration) use IPv4.
#if LLNET_AF & LLNET_AF_IPV6
	if(length >= sizeof(struct in6_addr)){
		*((struct in6_addr*)result) = in6addr_any;
		return sizeof(struct in6_addr);
	}
#else // only IPv4
	if(length >= sizeof(struct in_addr)){
		*((in_addr_t*)result) = llnet_htonl(INADDR_ANY);
		return sizeof(in_addr_t);
	}
#endif

	return J_EINVAL;
}

int32_t LLNET_NETWORKADDRESS_IMPL_loopbackAddress(int8_t* result, int32_t length, uint8_t retry){
	LLNET_DEBUG_TRACE("%s\n", __func__);

// If IPv6 or IPv4+IPv6 configuration, then use IPv6. Otherwise (only IPv4 configuration) use IPv4.
#if LLNET_AF & LLNET_AF_IPV6
	if(length >= sizeof(struct in6_addr)){
		*((struct in6_addr*)result) = in6addr_loopback;
		return sizeof(struct in6_addr);
	}
#else // only IPv4
	if(length >= sizeof(struct in_addr)){
		*((in_addr_t*)result) = llnet_htonl(INADDR_LOOPBACK);
		return sizeof(in_addr_t);
	}
#endif

	return J_EINVAL;
}

#ifdef __cplusplus
	}
#endif
