@echo off

REM BAT
REM Copyright 2020 MicroEJ Corp.
REM This software has been designed or modified by MicroEJ Corp.
REM MicroEJ Corp. grants to THALES the non-exclusive right to freely use, modify and distribute this software.

REM 'build.bat' implementation for Gemalto EXS82 Embedded Processing SDK.

REM 'build.bat' is responsible for producing the executable file 
REM then copying this executable file to the current directory where it has been executed to a file named 'application.out'

CALL "%~dp0\set_project_env.bat"
IF %ERRORLEVEL% NEQ 0 (
	EXIT /B %ERRORLEVEL%
)

REM Save application current directory and jump one level above scripts
SET CURRENT_DIRECTORY=%CD%
CD "%~dp0\..\"

set MEJ_CORE_INC=core\inc
set MEJ_CORE_SRC=core\src\*.c
set MEJ_NET_INC=net\inc
set MEJ_NET_SRC=net\src\*.c
set MEJ_ECOM_MOBILE_INC=ecom-mobile\inc
set MEJ_ECOM_MOBILE_SRC=ecom-mobile\src\*.c
set MEJ_FS_INC=fs\inc
set MEJ_FS_SRC=fs\src\*.c
set MEJ_SSL_INC=ssl\inc
set MEJ_SSL_SRC=ssl\src\*.c
set MEJ_SEC_INC=security\inc
set MEJ_SEC_SRC=security\src\*.c
set MEJ_UI_SRC=ui\src\*.c
set MEJ_UTIL_INC=util\inc
set MEJ_UTIL_SRC=util\src\*.c
set MEJ_GNSS_SRC=gnss\src\*.c
set MEJ_FS_INC=fs\inc\
set MEJ_FS_SRC=fs\src\*.c
set MEJ_NET_INC=net\inc\
set MEJ_NET_SRC=net\src\*.c
set MEJ_ECOM_MOBILE_SRC=ecom-mobile\src\*.c
set MEJ_PLATFORM_INC=platform\inc
set MEJ_PLATFORM_LIB=platform\lib
set MEJ_PLATFORM_LIBS=%MEJ_PLATFORM_LIB%\*.a
set MEJ_BIN_PATH=bin
set MEJ_APP=platform\lib\microejapp.o

set DAM_RO_BASE=0x42000000

set LLVM_ROOT_PATH=%GEMALTO_SDK%\tools\windows\llvm
set TOOLCHAIN_PATH=%LLVM_ROOT_PATH%\bin
set TOOLCHAIN_PATH_STANDARDS=%LLVM_ROOT_PATH%\armv7m-none-eabi\libc\include
set LLVMLIB=%LLVM_ROOT_PATH%\lib\clang\4.0.3\lib
set LLVMLINK_PATH=%LLVM_ROOT_PATH%\tools\bin
set DAM_INC_BASE=%GEMALTO_SDK%\common\include
set DAM_LIB_PATH=%GEMALTO_SDK%\common\libs

set BUILD_PATH=build
set DAM_DAM_DEMO_LD_PATH=build

set DAM_LIBNAME=txm_lib.lib
set TIMER_LIBNAME=timer_dam_lib.lib
set DIAG_LIB_NAME=diag_dam_lib.lib
set QMI_LIB_NAME=qcci_dam_lib.lib
set QMI_QCCLI_LIB_NAME=IDL_DAM_LIB.lib

set DAM_ELF_NAME=%GEMALTO_APPNAME%.elf
set DAM_TARGET_BIN=%GEMALTO_APPNAME%.bin
set DAM_MAP_NAME=%GEMALTO_APPNAME%.map

RD /S /Q %MEJ_BIN_PATH%
RD /S /Q %BUILD_PATH%

IF NOT EXIST %BUILD_PATH% (
	MKDIR %BUILD_PATH%
)

IF NOT EXIST %MEJ_BIN_PATH% (
	MKDIR %MEJ_BIN_PATH%
)

ECHO Renaming microejapp.o sections
%LLVMLINK_PATH%\arm-elfcopy.exe --rename-section _java_heap=.bss._java_heap --rename-section _java_immortals=.bss._java_immortals --rename-section ICETEA_HEAP=.bss.ICETEA_HEAP --rename-section .bss.vm.stacks.java=.bss.vm.stacks.java --rename-section .bss.microui.display.imagesHeap=.bss.microui.display.imagesHeap --rename-section .text.soar=.rodata.soar --rename-section .text.features.installed=.rodata.features.installed --rename-section .shieldedplug=.rodata.shieldedplug %MEJ_APP%

IF %ERRORLEVEL%==0 GOTO proceed
IF %ERRORLEVEL%==1 GOTO exit
:proceed

ECHO Application RO base selected = %DAM_RO_BASE%

SET DAM_CPPFLAGS=-DQAPI_TXM_MODULE -DTXM_MODULE -DGINA_TXM_MODULE -DTX_DAM_QC_CUSTOMIZATIONS -DTX_ENABLE_PROFILING -DTX_ENABLE_EVENT_TRACE -DTX_DISABLE_NOTIFY_CALLBACKS  -DFX_FILEX_PRESENT -DTX_ENABLE_IRQ_NESTING  -DTX3_CHANGES

SET DAM_CFLAGS=-marm -target armv7m-none-musleabi -mfloat-abi=softfp -mfpu=none -mcpu=cortex-a7 -mno-unaligned-access  -fms-extensions -Osize -fshort-enums -Wbuiltin-macro-redefined

SET DAM_INCPATHS=-I %DAM_INC_BASE% -I %DAM_INC_BASE%\threadx_api  -I %DAM_INC_BASE%\qapi -I %DAM_INC_BASE%\gina -I %TOOLCHAIN_PATH_STANDARDS% -I %LLVMLIB% -I %MEJ_PLATFORM_INC% -I %MEJ_CORE_INC% -I %MEJ_NET_INC% -I %MEJ_NET_INC% -I %MEJ_SSL_INC% -I %MEJ_SEC_INC% -I %MEJ_UTIL_INC% -I %MEJ_FS_INC%

ECHO Compiling %APPNAME% application

%TOOLCHAIN_PATH%\clang.exe -E  %DAM_CPPFLAGS% %DAM_CFLAGS% txm_module_preamble_llvm.S > %BUILD_PATH%\txm_module_preamble_llvm_pp.S

IF %ERRORLEVEL%==0 GOTO proceed
IF %ERRORLEVEL%==1 GOTO exit
:proceed

%TOOLCHAIN_PATH%\clang.exe  -c %DAM_CPPFLAGS% %DAM_CFLAGS% %BUILD_PATH%\txm_module_preamble_llvm_pp.S -o %BUILD_PATH%\txm_module_preamble_llvm.o

IF %ERRORLEVEL%==0 GOTO proceed
IF %ERRORLEVEL%==1 GOTO exit
:proceed

%TOOLCHAIN_PATH%\clang.exe -c %DAM_CPPFLAGS% %DAM_CFLAGS% %DAM_INCPATHS% %MEJ_CORE_SRC% %MEJ_NET_SRC% %MEJ_SSL_SRC% %MEJ_SEC_SRC% %MEJ_UTIL_SRC% %MEJ_GNSS_SRC% %MEJ_ECOM_MOBILE_SRC% %MEJ_FS_SRC%

IF %ERRORLEVEL%==0 (
	ECHO Compilation succeeded
	MOVE *.o %BUILD_PATH%
	ECHO Linking %APPNAME% application

	%TOOLCHAIN_PATH%\clang++.exe -d -o %BUILD_PATH%\%DAM_ELF_NAME% -target armv7m-none-musleabi -fuse-ld=qcld -lc++ -Wl,-mno-unaligned-access -fuse-baremetal-sysroot -fno-use-baremetal-crt -Wl,-entry=%DAM_RO_BASE% %BUILD_PATH%\txm_module_preamble_llvm.o -Wl,-T%GEMALTO_APPNAME%.ld -Wl,-Map=%BUILD_PATH%\%DAM_MAP_NAME%,-gc-sections -Wl,-gc-sections -Wl,--start-group %BUILD_PATH%\*.o %DAM_LIB_PATH%\*.lib %MEJ_PLATFORM_LIB%\*.a %MEJ_APP% -Wl,--end-group
	%PYTHON27_PATH% %LLVMLINK_PATH%\llvm-elf-to-hex.py --bin %BUILD_PATH%\%DAM_ELF_NAME% --output %MEJ_BIN_PATH%\%DAM_TARGET_BIN%

	COPY %BUILD_PATH%\%DAM_ELF_NAME% %CURRENT_DIRECTORY%\application.out
	ECHO %APPNAME% application is built at %MEJ_BIN_PATH%\%DAM_TARGET_BIN%
) ELSE (
	ECHO Compilation failed with errors
)

REM Restore application directory
CD "%CURRENT_DIRECTORY%"

:exit
EXIT /B %ERRORLEVEL%
